%bcond_with java

Summary:       Library and tools for WebP image files
Name:          libwebp
Version:       1.4.0
Release:       1%{?dist}
License:       BSD
URL:           http://webmproject.org/
Source0:       http://downloads.webmproject.org/releases/webp/%{name}-%{version}.tar.gz

Patch3000:     libwebp-freeglut.patch
Patch3001:     libwebp-cmakedir.patch
Patch3002:     libwebp-rpath.patch

BuildRequires: cmake gcc freeglut-devel
BuildRequires: libjpeg-devel libpng-devel giflib-devel libtiff-devel

%if %{with java}
BuildRequires: swig java-devel jpackage-utils
%endif

%description
This package contains the library that can be used in other programs
to add WebP support, as well as the command line tools 'cwebp' and 'dwebp'
to compress and decompress images respectively.
See https://developers.google.com/speed/webp for details on the image format.


%package tools
Summary:       Command line tools for WebP

%description tools
Command line tools cwebp and dwebp for converting images
to and from the WebP format, as well as tools for viewing,
muxing and animating WebP images.


%package devel
Summary:       Development files for libwebp
Requires:      %{name} = %{version}-%{release}

%description devel
Libraries and headers for developing with WebP.

%if %{with java}
%package java
Summary:       Java bindings for libwebp
Requires:      %{name} = %{version}-%{release}
Requires:      java-headless jpackage-utils

%description java
Java bindings for libwebp.
%endif

%prep
%autosetup -n %{name}-%{version} -p1


%build
%cmake
%cmake_build

%if %{with java}
cd swig
rm -rf libwebp.jar libwebp_java_wrap.c
mkdir -p java/com/google/webp
swig -ignoremissing -I../src -java \
    -package com.google.webp  \
    -outdir java/com/google/webp \
    -o libwebp_java_wrap.c libwebp.swig

gcc %{__global_ldflags} %{optflags} -shared \
    -I/usr/lib/jvm/java/include \
    -I/usr/lib/jvm/java/include/linux \
    -I../src \
    -L../src/.libs -lwebp libwebp_java_wrap.c \
    -o libwebp_jni.so

cd java
javac com/google/webp/libwebp.java
jar cvf ../libwebp.jar com/google/webp/*.class
%endif


%install
%cmake_install
find %{buildroot}/%{_libdir} -type f -name "*.la" -delete

%if %{with java}
install -d %{buildroot}/%{_libdir}/%{name}-java
cp swig/*.jar swig/*.so %{buildroot}/%{_libdir}/%{name}-java/
%endif

%check
%ctest

%files
%license COPYING
%doc README.md PATENTS NEWS AUTHORS
%{_libdir}/%{name}.so.7*
%{_libdir}/%{name}decoder.so.3*
%{_libdir}/%{name}demux.so.2*
%{_libdir}/%{name}mux.so.3*
%{_libdir}/libsharpyuv.so.0*

%files devel
%{_libdir}/%{name}.so
%{_libdir}/%{name}decoder.so
%{_libdir}/%{name}demux.so
%{_libdir}/%{name}mux.so
%{_libdir}/libsharpyuv.so
%{_includedir}/webp/
%{_libdir}/pkgconfig/libwebp.pc
%{_libdir}/pkgconfig/libwebpdecoder.pc
%{_libdir}/pkgconfig/libwebpdemux.pc
%{_libdir}/pkgconfig/libwebpmux.pc
%{_libdir}/pkgconfig/libsharpyuv.pc
%{_libdir}/cmake/WebP/

%files tools
%{_bindir}/cwebp
%{_bindir}/dwebp
%{_bindir}/gif2webp
%{_bindir}/img2webp
%{_bindir}/webpinfo
%{_bindir}/webpmux
%{_bindir}/vwebp
%{_mandir}/man*/*

%if %{with java}
%files java
%doc libwebp_jni_example.java
%{_libdir}/%{name}-java/
%endif

%changelog
* Fri Jul 19 2024 Upgrade Robot <upbot@opencloudos.tech> - 1.4.0-1
- Upgrade to version 1.4.0

* Mon Oct 9 2023 Shuo Wang <abushwang@tencent.com> - 1.3.2-1
- update to 1.3.2
- security fix for lossless decoder (chromium: #1479274, CVE-2023-4863)

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 22 2023 Shuo Wang <abushwang@tencent.com> - 1.3.1-3
- Rebuilt for freeglut 3.4.0

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 1.3.1-2
- Rebuilt for libtiff 4.5.1

* Wed Aug 2 2023 Shuo Wang <abushwang@tencent.com> - 1.3.1-1
- update to 1.3.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.2-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.2-3
- Rebuilt for OpenCloudOS Stream 23

* Mon Sep 12 2022 rockerzhu <rockerzhu@tencent.com> - 1.2.2-2
- Disable java by default

* Fri May 13 2022 rockerzhu <rockerzhu@tencent.com> - 1.2.2-1
- Initial build
